@@ -1,87 +1,95 @@
 <?php
-/*
- * @version $Id: report.infocom.conso.php 18771 2012-06-29 08:49:19Z moyo $
- -------------------------------------------------------------------------
- GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2012 by the INDEPNET Development Team.
-
- http://indepnet.net/   http://glpi-project.org
- -------------------------------------------------------------------------
-
- LICENSE
-
- This file is part of GLPI.
-
- GLPI is free software; you can redistribute it and/or modify
- it under the terms of the GNU General Public License as published by
- the Free Software Foundation; either version 2 of the License, or
- (at your option) any later version.
-
- GLPI is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- GNU General Public License for more details.
-
- You should have received a copy of the GNU General Public License
- along with GLPI. If not, see <http://www.gnu.org/licenses/>.
- --------------------------------------------------------------------------
+/**
+ * ---------------------------------------------------------------------
+ * GLPI - Gestionnaire Libre de Parc Informatique
+ * Copyright (C) 2015-2017 Teclib' and contributors.
+ *
+ * http://glpi-project.org
+ *
+ * based on GLPI - Gestionnaire Libre de Parc Informatique
+ * Copyright (C) 2003-2014 by the INDEPNET Development Team.
+ *
+ * ---------------------------------------------------------------------
+ *
+ * LICENSE
+ *
+ * This file is part of GLPI.
+ *
+ * GLPI is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * GLPI is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with GLPI. If not, see <http://www.gnu.org/licenses/>.
+ * ---------------------------------------------------------------------
  */
 
-// ----------------------------------------------------------------------
-// Original Author of file: Julien Dombre
-// Purpose of file:
-// ----------------------------------------------------------------------
+/** @file
+* @brief
+*/
 
-define('GLPI_ROOT', '..');
-include (GLPI_ROOT . "/inc/includes.php");
+include ('../inc/includes.php');
 
-Session::checkRight("reports", "r");
+Session::checkRight("reports", READ);
 
-Html::header($LANG['Menu'][6], $_SERVER['PHP_SELF'], "utils", "report");
+Html::header(Report::getTypeName(Session::getPluralNumber()), $_SERVER['PHP_SELF'], "tools", "report");
 
 if (empty($_POST["date1"]) && empty($_POST["date2"])) {
-   $year = date("Y")-1;
-   $_POST["date1"] = date("Y-m-d", mktime(1,0,0,date("m"),date("d"),$year));
+   $year           = date("Y")-1;
+   $_POST["date1"] = date("Y-m-d", mktime(1, 0, 0, date("m"), date("d"), $year));
    $_POST["date2"] = date("Y-m-d");
 }
 
 if (!empty($_POST["date1"])
     && !empty($_POST["date2"])
-    && strcmp($_POST["date2"], $_POST["date1"]) < 0) {
+    && (strcmp($_POST["date2"], $_POST["date1"]) < 0)) {
 
-   $tmp = $_POST["date1"];
+   $tmp            = $_POST["date1"];
    $_POST["date1"] = $_POST["date2"];
    $_POST["date2"] = $tmp;
 }
 
+$stat = new Stat();
+$chart_opts =  [
+   'width'  => '90%',
+   'legend' => false
+];
+
 Report::title();
 
 echo "\n<form method='post' name='form' action='".$_SERVER['PHP_SELF']."'>";
 echo "<table class='tab_cadre'><tr class='tab_bg_2'>";
-echo "<td class='right'>".$LANG['search'][8]."&nbsp;:&nbsp;</td><td>";
-Html::showDateFormItem("date1", $_POST["date1"]);
+echo "<td class='right'>".__('Start date')."</td><td>";
+Html::showDateField("date1", ['value' => $_POST["date1"]]);
 echo "</td><td rowspan='2' class='center'>";
-echo "<input type='submit' class='button' name='submit' value=\"".$LANG['buttons'][7]."\"></td></tr>\n";
-echo "<tr class='tab_bg_2'><td class='right'>".$LANG['search'][9]."&nbsp;:&nbsp;</td><td>";
-Html::showDateFormItem("date2", $_POST["date2"]);
+echo "<input type='submit' class='submit' name='submit' value=\"".__s('Display report')."\"></td>".
+     "</tr>\n";
+echo "<tr class='tab_bg_2'><td class='right'>".__('End date')."</td><td>";
+Html::showDateField("date2", ['value' => $_POST["date2"]]);
 echo "</td></tr>";
 echo "</table>\n";
 Html::closeForm();
 
 $valeurtot           = 0;
 $valeurnettetot      = 0;
-$valeurnettegraphtot = array();
-$valeurgraphtot      = array();
+$valeurnettegraphtot = [];
+$valeurgraphtot      = [];
 
 
 /** Display an infocom report for items like consumables
  *
- * @param $itemtype item type
- * @param $begin begin date
- * @param $end end date
+ * @param $itemtype  item type
+ * @param $begin     begin date
+ * @param $end       end date
 **/
 function display_infocoms_report($itemtype, $begin, $end) {
-   global $DB, $valeurtot, $valeurnettetot, $valeurnettegraphtot, $valeurgraphtot, $LANG, $CFG_GLPI;
+   global $DB, $valeurtot, $valeurnettetot, $valeurnettegraphtot, $valeurgraphtot, $CFG_GLPI, $stat, $chart_opts;
 
    $itemtable = getTableForItemType($itemtype);
    $query = "SELECT `glpi_infocoms`.*
@@ -94,19 +102,19 @@ function display_infocoms_report($itemtype, $begin, $end) {
       case 'Consumable' :
          $query .= " INNER JOIN `glpi_consumableitems`
                         ON (`glpi_consumables`.`consumableitems_id` = `glpi_consumableitems`.`id`) ".
-                     getEntitiesRestrictRequest("WHERE","glpi_consumableitems");
+                     getEntitiesRestrictRequest("WHERE", "glpi_consumableitems");
          break;
 
       case 'Cartridge' :
          $query .= " INNER JOIN `glpi_cartridgeitems`
                         ON (`glpi_cartridges`.`cartridgeitems_id` = `glpi_cartridgeitems`.`id`) ".
-                     getEntitiesRestrictRequest("WHERE","glpi_cartridgeitems");
+                     getEntitiesRestrictRequest("WHERE", "glpi_cartridgeitems");
          break;
 
       case 'SoftwareLicense' :
          $query .= " INNER JOIN `glpi_softwares`
                         ON (`glpi_softwarelicenses`.`softwares_id` = `glpi_softwares`.`id`) ".
-                     getEntitiesRestrictRequest("WHERE","glpi_softwarelicenses");
+                     getEntitiesRestrictRequest("WHERE", "glpi_softwarelicenses");
          break;
    }
 
@@ -120,18 +128,18 @@ function display_infocoms_report($itemtype, $begin, $end) {
    }
 
    if ($result = $DB->query($query)) {
-      if ($DB->numrows($result) >0) {
-         $item = new $itemtype();
+      if (($DB->numrows($result) > 0)
+          && ($item = getItemForItemtype($itemtype))) {
 
-         echo "<h2>".$item->getTypeName()."</h2>";
+         echo "<h2>".$item->getTypeName(1)."</h2>";
          echo "<table class='tab_cadre'>";
 
          $valeursoustot      = 0;
          $valeurnettesoustot = 0;
-         $valeurnettegraph   = array();
-         $valeurgraph        = array();
+         $valeurnettegraph   = [];
+         $valeurgraph        = [];
 
-         while ($line=$DB->fetch_array($result)) {
+         while ($line=$DB->fetch_assoc($result)) {
             if ($itemtype == 'SoftwareLicense') {
                $item->getFromDB($line["items_id"]);
 
@@ -150,14 +158,14 @@ function display_infocoms_report($itemtype, $begin, $end) {
                                           $line["sink_coeff"], $line["buy_date"], $line["use_date"],
                                           $CFG_GLPI["date_tax"], "n");
 
-            $tmp = Infocom::Amort($line["sink_type"], $line["value"], $line["sink_time"],
-                                  $line["sink_coeff"], $line["buy_date"], $line["use_date"],
-                                  $CFG_GLPI["date_tax"], "all");
+            $tmp         = Infocom::Amort($line["sink_type"], $line["value"], $line["sink_time"],
+                                          $line["sink_coeff"], $line["buy_date"], $line["use_date"],
+                                          $CFG_GLPI["date_tax"], "all");
 
-            if (is_array($tmp) && count($tmp) >0) {
+            if (is_array($tmp) && (count($tmp) > 0)) {
                foreach ($tmp["annee"] as $key => $val) {
 
-                  if ($tmp["vcnetfin"][$key] >0) {
+                  if ($tmp["vcnetfin"][$key] > 0) {
                      if (!isset($valeurnettegraph[$val])) {
                         $valeurnettegraph[$val] = 0;
                      }
@@ -168,7 +176,7 @@ function display_infocoms_report($itemtype, $begin, $end) {
             }
 
             if (!empty($line["buy_date"])) {
-               $year = substr($line["buy_date"],0,4);
+               $year = substr($line["buy_date"], 0, 4);
 
                if ($line["value"] >0) {
                   if (!isset($valeurgraph[$year])) {
@@ -178,10 +186,14 @@ function display_infocoms_report($itemtype, $begin, $end) {
                }
 
             }
-            $valeurnettesoustot += str_replace(" ","",$valeurnette);
+
+            $valeurnette = str_replace([" ", "-"], ["", ""], $valeurnette);
+            if (!empty($valeurnette)) {
+               $valeurnettesoustot += $valeurnette;
+            }
          }
 
-         $valeurtot += $valeursoustot;
+         $valeurtot      += $valeursoustot;
          $valeurnettetot += $valeurnettesoustot;
 
          if (count($valeurnettegraph) >0) {
@@ -196,9 +208,17 @@ function display_infocoms_report($itemtype, $begin, $end) {
                $valeurnettegraphtot[$key] += $valeurnettegraph[$key];
             }
 
-            Stat::showGraph(array($LANG['financial'][81] => $valeurnettegraphdisplay),
-                            array('title' => $LANG['financial'][81],
-                                  'width' => 400));
+            $stat->displayLineGraph(
+               sprintf(
+                   __('%1$s account net value'),
+                   $item->getTypeName(1)
+               ),
+               array_keys($valeurnettegraphdisplay), [
+                  [
+                     'data' => $valeurnettegraphdisplay
+                  ]
+               ], $chart_opts
+            );
 
             echo "</td></tr>\n";
          }
@@ -214,11 +234,17 @@ function display_infocoms_report($itemtype, $begin, $end) {
                }
                $valeurgraphtot[$key] += $valeurgraph[$key];
             }
-
-            Stat::showGraph(array($LANG['financial'][21] => $valeurgraphdisplay),
-                            array('title' => $LANG['financial'][21],
-                                  'width' => 400));
-
+            $stat->displayLineGraph(
+               sprintf(
+                  __('%1$s value'),
+                  $item->getTypeName(1)
+               ),
+               array_keys($valeurgraphdisplay), [
+                  [
+                     'data' => $valeurgraphdisplay
+                  ]
+               ], $chart_opts
+            );
             echo "</td></tr>";
          }
          echo "</table>\n";
@@ -229,18 +255,18 @@ function display_infocoms_report($itemtype, $begin, $end) {
 }
 
 
-$types = array('Cartridge', 'Consumable', 'SoftwareLicense');
+$types = ['Cartridge', 'Consumable', 'SoftwareLicense'];
 
 $i = 0;
 echo "<table width='90%'><tr><td class='center top'>";
-while (count($types)>0) {
+while (count($types) > 0) {
    $type = array_shift($types);
 
-   if (display_infocoms_report($type,$_POST["date1"],$_POST["date2"])) {
+   if (display_infocoms_report($type, $_POST["date1"], $_POST["date2"])) {
       echo "</td>";
       $i++;
 
-      if (($i%2)==0) {
+      if (($i%2) == 0) {
          echo "</tr><tr>";
       }
 
@@ -248,27 +274,40 @@ while (count($types)>0) {
    }
 }
 
-if (($i%2)==0) {
+if (($i%2) == 0) {
    echo "&nbsp;</td><td>&nbsp;";
 }
 
 echo "&nbsp;</td></tr></table>";
 
-echo "<div class='center'><h3>".$LANG['common'][33]."&nbsp;: ".
-      $LANG['financial'][21]." = ".Html::formatNumber($valeurtot)." - ".
-      $LANG['financial'][81]." = ".Html::formatNumber($valeurnettetot)."</h3></div>\n";
+//TRANS: %1$s and %2$s are values
+$tmpmsg = sprintf(__('Total: Value=%1$s - Account net value=%2$s'),
+                  Html::formatNumber($valeurtot), Html::formatNumber($valeurnettetot));
+echo "<div class='center'><h3>$tmpmsg</h3></div>\n";
 
 if (count($valeurnettegraphtot) >0) {
    $valeurnettegraphtotdisplay = array_map('round', $valeurnettegraphtot);
-   Stat::showGraph(array($LANG['financial'][81] => $valeurnettegraphtotdisplay),
-                   array('title' => $LANG['financial'][81]));
 
+   $stat->displayLineGraph(
+      __('Total account net value'),
+      array_keys($valeurnettegraphtotdisplay), [
+         [
+            'data' => $valeurnettegraphtotdisplay
+         ]
+      ], $chart_opts
+   );
 }
 if (count($valeurgraphtot) >0) {
    $valeurgraphtotdisplay = array_map('round', $valeurgraphtot);
-   Stat::showGraph(array($LANG['financial'][21] => $valeurgraphtotdisplay),
-                   array('title' => $LANG['financial'][21]));
+
+   $stat->displayLineGraph(
+      __('Total value'),
+      array_keys($valeurgraphtotdisplay), [
+         [
+            'data' => $valeurgraphtotdisplay
+         ]
+      ], $chart_opts
+   );
 }
 
 Html::footer();
-?>
\ No newline at end of file
